"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

import requests
from typing import Optional, TypeVar
from binance_common.configuration import ConfigurationRestAPI
from binance_common.models import ApiResponse
from binance_common.signature import Signers
from binance_common.utils import send_request
from .api.eth_staking_api import EthStakingApi
from .api.on_chain_yields_api import OnChainYieldsApi
from .api.sol_staking_api import SolStakingApi

from .models import EthStakingAccountResponse
from .models import GetCurrentEthStakingQuotaResponse
from .models import GetEthRedemptionHistoryResponse
from .models import GetEthStakingHistoryResponse
from .models import GetWbethRateHistoryResponse
from .models import GetWbethRewardsHistoryResponse
from .models import GetWbethUnwrapHistoryResponse
from .models import GetWbethWrapHistoryResponse
from .models import RedeemEthResponse
from .models import SubscribeEthStakingResponse
from .models import WrapBethResponse
from .models import GetOnChainYieldsLockedPersonalLeftQuotaResponse
from .models import GetOnChainYieldsLockedProductListResponse
from .models import GetOnChainYieldsLockedProductPositionResponse
from .models import GetOnChainYieldsLockedRedemptionRecordResponse
from .models import GetOnChainYieldsLockedRewardsHistoryResponse
from .models import GetOnChainYieldsLockedSubscriptionPreviewResponse
from .models import GetOnChainYieldsLockedSubscriptionRecordResponse
from .models import OnChainYieldsAccountResponse
from .models import RedeemOnChainYieldsLockedProductResponse
from .models import SetOnChainYieldsLockedAutoSubscribeResponse
from .models import SetOnChainYieldsLockedProductRedeemOptionResponse
from .models import SubscribeOnChainYieldsLockedProductResponse
from .models import ClaimBoostRewardsResponse
from .models import GetBnsolRateHistoryResponse
from .models import GetBnsolRewardsHistoryResponse
from .models import GetBoostRewardsHistoryResponse
from .models import GetSolRedemptionHistoryResponse
from .models import GetSolStakingHistoryResponse
from .models import GetSolStakingQuotaDetailsResponse
from .models import GetUnclaimedRewardsResponse
from .models import RedeemSolResponse
from .models import SolStakingAccountResponse
from .models import SubscribeSolStakingResponse


T = TypeVar("T")


class StakingRestAPI:
    def __init__(
        self,
        configuration: ConfigurationRestAPI,
    ) -> None:
        self.configuration = configuration
        self._session = requests.Session()
        self._signer = (
            Signers.get_signer(
                configuration.private_key, configuration.private_key_passphrase
            )
            if configuration.private_key is not None
            else None
        )

        self._ethStakingApi = EthStakingApi(
            self.configuration, self._session, self._signer
        )
        self._onChainYieldsApi = OnChainYieldsApi(
            self.configuration, self._session, self._signer
        )
        self._solStakingApi = SolStakingApi(
            self.configuration, self._session, self._signer
        )

    def send_request(
        self, endpoint: str, method: str, params: Optional[dict] = None
    ) -> ApiResponse[T]:
        """
        Sends an request to the Binance REST API.

        Args:
            endpoint (str): The API endpoint path to send the request to.
            method (str): The HTTP method to use for the request (e.g. "GET", "POST", "PUT", "DELETE").
            params (Optional[dict]): The request payload as a dictionary, or None if no payload is required.

        Returns:
            ApiResponse[T]: The API response, where T is the expected response type.
        """
        return send_request[T](
            self._session, self.configuration, method, endpoint, params
        )

    def send_signed_request(
        self, endpoint: str, method: str, params: Optional[dict] = None
    ) -> ApiResponse[T]:
        """
        Sends a signed request to the Binance REST API.

        Args:
            endpoint (str): The API endpoint path to send the request to.
            method (str): The HTTP method to use for the request (e.g. "GET", "POST", "PUT", "DELETE").
            params (Optional[dict]): The request payload as a dictionary, or None if no payload is required.

        Returns:
            ApiResponse[T]: The API response, where T is the expected response type.
        """
        return send_request[T](
            self._session,
            self.configuration,
            method,
            endpoint,
            params,
            is_signed=True,
            signer=self._signer,
        )

    def eth_staking_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[EthStakingAccountResponse]:
        """
                ETH Staking account(USER_DATA)

                ETH Staking account

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[EthStakingAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.eth_staking_account(recv_window)

    def get_current_eth_staking_quota(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetCurrentEthStakingQuotaResponse]:
        """
                Get current ETH staking quota(USER_DATA)

                Get current ETH staking quota

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetCurrentEthStakingQuotaResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_current_eth_staking_quota(recv_window)

    def get_eth_redemption_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetEthRedemptionHistoryResponse]:
        """
                Get ETH redemption history(USER_DATA)

                Get ETH redemption history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetEthRedemptionHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_eth_redemption_history(
            start_time, end_time, current, size, recv_window
        )

    def get_eth_staking_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetEthStakingHistoryResponse]:
        """
                Get ETH staking history(USER_DATA)

                Get ETH staking history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetEthStakingHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_eth_staking_history(
            start_time, end_time, current, size, recv_window
        )

    def get_wbeth_rate_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethRateHistoryResponse]:
        """
                Get WBETH Rate History(USER_DATA)

                Get WBETH Rate History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethRateHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_wbeth_rate_history(
            start_time, end_time, current, size, recv_window
        )

    def get_wbeth_rewards_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethRewardsHistoryResponse]:
        """
                Get WBETH rewards history(USER_DATA)

                Get WBETH rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_wbeth_rewards_history(
            start_time, end_time, current, size, recv_window
        )

    def get_wbeth_unwrap_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethUnwrapHistoryResponse]:
        """
                Get WBETH unwrap history(USER_DATA)

                Get WBETH unwrap history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethUnwrapHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_wbeth_unwrap_history(
            start_time, end_time, current, size, recv_window
        )

    def get_wbeth_wrap_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethWrapHistoryResponse]:
        """
                Get WBETH wrap history(USER_DATA)

                Get WBETH wrap history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethWrapHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.get_wbeth_wrap_history(
            start_time, end_time, current, size, recv_window
        )

    def redeem_eth(
        self,
        amount: float = None,
        asset: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemEthResponse]:
        """
                Redeem ETH(TRADE)

                Redeem WBETH or BETH and get ETH

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemEthResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.redeem_eth(amount, asset, recv_window)

    def subscribe_eth_staking(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeEthStakingResponse]:
        """
                Subscribe ETH Staking(TRADE)

                Subscribe ETH Staking

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeEthStakingResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.subscribe_eth_staking(amount, recv_window)

    def wrap_beth(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[WrapBethResponse]:
        """
                Wrap BETH(TRADE)

                Wrap BETH

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[WrapBethResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._ethStakingApi.wrap_beth(amount, recv_window)

    def get_on_chain_yields_locked_personal_left_quota(
        self,
        project_id: str = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedPersonalLeftQuotaResponse]:
        """
                Get On-chain Yields Locked Personal Left Quota (USER_DATA)

                Get On-chain Yields Locked Personal Left Quota

        Weight: 50

                Args:
                    project_id (str):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedPersonalLeftQuotaResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_personal_left_quota(
            project_id, recv_window
        )

    def get_on_chain_yields_locked_product_list(
        self,
        asset: Optional[str] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedProductListResponse]:
        """
                Get On-chain Yields Locked Product List (USER_DATA)

                Get available On-chain Yields Locked product list

        * Get available On-chain Yields Locked product list

        Weight: 50

                Args:
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedProductListResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_product_list(
            asset, current, size, recv_window
        )

    def get_on_chain_yields_locked_product_position(
        self,
        asset: Optional[str] = None,
        position_id: Optional[int] = None,
        project_id: Optional[str] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedProductPositionResponse]:
        """
                Get On-chain Yields Locked Product Position (USER_DATA)

                Get On-chain Yields Locked Product Position

        Weight: 50

                Args:
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    position_id (Optional[int]):
                    project_id (Optional[str]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedProductPositionResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_product_position(
            asset, position_id, project_id, current, size, recv_window
        )

    def get_on_chain_yields_locked_redemption_record(
        self,
        position_id: Optional[int] = None,
        redeem_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedRedemptionRecordResponse]:
        """
                Get On-chain Yields Locked Redemption Record (USER_DATA)

                Get On-chain Yields Locked Redemption Record

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    position_id (Optional[int]):
                    redeem_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedRedemptionRecordResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_redemption_record(
            position_id,
            redeem_id,
            asset,
            start_time,
            end_time,
            current,
            size,
            recv_window,
        )

    def get_on_chain_yields_locked_rewards_history(
        self,
        position_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedRewardsHistoryResponse]:
        """
                Get On-chain Yields Locked Rewards History (USER_DATA)

                Get On-chain Yields Locked Rewards History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    position_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_rewards_history(
            position_id, asset, start_time, end_time, current, size, recv_window
        )

    def get_on_chain_yields_locked_subscription_preview(
        self,
        project_id: str = None,
        amount: float = None,
        auto_subscribe: Optional[bool] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedSubscriptionPreviewResponse]:
        """
                Get On-chain Yields Locked Subscription Preview (USER_DATA)

                Get On-chain Yields Locked Subscription Preview

        Weight: 50

                Args:
                    project_id (str):
                    amount (float): Amount in SOL.
                    auto_subscribe (Optional[bool]): true or false, default true.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedSubscriptionPreviewResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_subscription_preview(
            project_id, amount, auto_subscribe, recv_window
        )

    def get_on_chain_yields_locked_subscription_record(
        self,
        purchase_id: Optional[str] = None,
        client_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedSubscriptionRecordResponse]:
        """
                Get On-chain Yields Locked Subscription Record (USER_DATA)

                Get On-chain Yields Locked Subscription Record

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    purchase_id (Optional[str]):
                    client_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedSubscriptionRecordResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.get_on_chain_yields_locked_subscription_record(
            purchase_id,
            client_id,
            asset,
            start_time,
            end_time,
            current,
            size,
            recv_window,
        )

    def on_chain_yields_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[OnChainYieldsAccountResponse]:
        """
                On-chain Yields Account (USER_DATA)

                On-chain Yields Account query

        Weight: 50

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[OnChainYieldsAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.on_chain_yields_account(recv_window)

    def redeem_on_chain_yields_locked_product(
        self,
        position_id: str = None,
        channel_id: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemOnChainYieldsLockedProductResponse]:
        """
                Redeem On-chain Yields Locked Product (TRADE)

                Redeem On-chain Yields Locked Product

        * You need to open `Enable Spot & Margin Trading` permission for the API Key which requests this endpoint.

        Weight: 1/3s per account

                Args:
                    position_id (str):
                    channel_id (Optional[str]):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemOnChainYieldsLockedProductResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.redeem_on_chain_yields_locked_product(
            position_id, channel_id, recv_window
        )

    def set_on_chain_yields_locked_auto_subscribe(
        self,
        position_id: str = None,
        auto_subscribe: bool = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SetOnChainYieldsLockedAutoSubscribeResponse]:
        """
                Set On-chain Yields Locked Auto Subscribe(USER_DATA)

                Set On-chain Yield locked auto subscribe

        Weight: 50

                Args:
                    position_id (str):
                    auto_subscribe (bool): true or false
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SetOnChainYieldsLockedAutoSubscribeResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.set_on_chain_yields_locked_auto_subscribe(
            position_id, auto_subscribe, recv_window
        )

    def set_on_chain_yields_locked_product_redeem_option(
        self,
        position_id: str = None,
        redeem_to: str = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SetOnChainYieldsLockedProductRedeemOptionResponse]:
        """
                Set On-chain Yields Locked Product Redeem Option(USER_DATA)

                Set On-chain Yields redeem option for Locked product

        Weight: 50

                Args:
                    position_id (str):
                    redeem_to (str): 'SPOT','FLEXIBLE'
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SetOnChainYieldsLockedProductRedeemOptionResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.set_on_chain_yields_locked_product_redeem_option(
            position_id, redeem_to, recv_window
        )

    def subscribe_on_chain_yields_locked_product(
        self,
        project_id: str = None,
        amount: float = None,
        auto_subscribe: Optional[bool] = None,
        source_account: Optional[str] = None,
        redeem_to: Optional[str] = None,
        channel_id: Optional[str] = None,
        client_id: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeOnChainYieldsLockedProductResponse]:
        """
                Subscribe On-chain Yields Locked Product(TRADE)

                Subscribe On-chain Yields Locked Product

        * You need to open `Enable Spot & Margin Trading` permission for the API Key which requests this endpoint.

        Weight: 200

                Args:
                    project_id (str):
                    amount (float): Amount in SOL.
                    auto_subscribe (Optional[bool]): true or false, default true.
                    source_account (Optional[str]): `SPOT`,`FUND`,`ALL`, default `SPOT`
                    redeem_to (Optional[str]): `SPOT`,`FLEXIBLE`, default `FLEXIBLE` Takes effect when Auto Subscribe is false
                    channel_id (Optional[str]):
                    client_id (Optional[str]):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeOnChainYieldsLockedProductResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._onChainYieldsApi.subscribe_on_chain_yields_locked_product(
            project_id,
            amount,
            auto_subscribe,
            source_account,
            redeem_to,
            channel_id,
            client_id,
            recv_window,
        )

    def claim_boost_rewards(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[ClaimBoostRewardsResponse]:
        """
                Claim Boost Rewards(TRADE)

                Claim Boost APR Airdrop Rewards

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[ClaimBoostRewardsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.claim_boost_rewards(recv_window)

    def get_bnsol_rate_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBnsolRateHistoryResponse]:
        """
                Get BNSOL Rate History(USER_DATA)

                Get BNSOL Rate History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBnsolRateHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_bnsol_rate_history(
            start_time, end_time, current, size, recv_window
        )

    def get_bnsol_rewards_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBnsolRewardsHistoryResponse]:
        """
                Get BNSOL rewards history(USER_DATA)

                Get BNSOL rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBnsolRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_bnsol_rewards_history(
            start_time, end_time, current, size, recv_window
        )

    def get_boost_rewards_history(
        self,
        type: str = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBoostRewardsHistoryResponse]:
        """
                Get Boost Rewards History(USER_DATA)

                Get Boost rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    type (str): "CLAIM", "DISTRIBUTE", default "CLAIM"
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBoostRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_boost_rewards_history(
            type, start_time, end_time, current, size, recv_window
        )

    def get_sol_redemption_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolRedemptionHistoryResponse]:
        """
                Get SOL redemption history(USER_DATA)

                Get SOL redemption history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolRedemptionHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_sol_redemption_history(
            start_time, end_time, current, size, recv_window
        )

    def get_sol_staking_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolStakingHistoryResponse]:
        """
                Get SOL staking history(USER_DATA)

                Get SOL staking history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolStakingHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_sol_staking_history(
            start_time, end_time, current, size, recv_window
        )

    def get_sol_staking_quota_details(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolStakingQuotaDetailsResponse]:
        """
                Get SOL staking quota details(USER_DATA)

                Get SOL staking quota

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolStakingQuotaDetailsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_sol_staking_quota_details(recv_window)

    def get_unclaimed_rewards(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetUnclaimedRewardsResponse]:
        """
                Get Unclaimed Rewards(USER_DATA)

                Get Unclaimed rewards

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetUnclaimedRewardsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.get_unclaimed_rewards(recv_window)

    def redeem_sol(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemSolResponse]:
        """
                Redeem SOL(TRADE)

                Redeem BNSOL get SOL

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemSolResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.redeem_sol(amount, recv_window)

    def sol_staking_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SolStakingAccountResponse]:
        """
                SOL Staking account(USER_DATA)

                SOL Staking account

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SolStakingAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.sol_staking_account(recv_window)

    def subscribe_sol_staking(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeSolStakingResponse]:
        """
                Subscribe SOL Staking(TRADE)

                Subscribe SOL Staking

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeSolStakingResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        return self._solStakingApi.subscribe_sol_staking(amount, recv_window)



from binance_sdk_staking.staking import Staking
from binance_common.errors import (
    ClientError,
    RequiredError,
    UnauthorizedError,
    ForbiddenError,
    TooManyRequestsError,
    RateLimitBanError,
    ServerError,
    NetworkError,
    NotFoundError,
    BadRequestError,
)
from binance_common.constants import (
    STAKING_REST_API_PROD_URL,
)

__all__ = [
    "Staking",
    "STAKING_REST_API_PROD_URL",
    "ClientError",
    "RequiredError",
    "UnauthorizedError",
    "ForbiddenError",
    "TooManyRequestsError",
    "RateLimitBanError",
    "ServerError",
    "NetworkError",
    "NotFoundError",
    "BadRequestError",
]



"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from typing import Optional
from requests import Session
from binance_common.configuration import ConfigurationRestAPI
from binance_common.errors import RequiredError
from binance_common.models import ApiResponse
from binance_common.signature import Signers
from binance_common.utils import send_request

from ..models import GetOnChainYieldsLockedPersonalLeftQuotaResponse
from ..models import GetOnChainYieldsLockedProductListResponse
from ..models import GetOnChainYieldsLockedProductPositionResponse
from ..models import GetOnChainYieldsLockedRedemptionRecordResponse
from ..models import GetOnChainYieldsLockedRewardsHistoryResponse
from ..models import GetOnChainYieldsLockedSubscriptionPreviewResponse
from ..models import GetOnChainYieldsLockedSubscriptionRecordResponse
from ..models import OnChainYieldsAccountResponse
from ..models import RedeemOnChainYieldsLockedProductResponse
from ..models import SetOnChainYieldsLockedAutoSubscribeResponse
from ..models import SetOnChainYieldsLockedProductRedeemOptionResponse
from ..models import SubscribeOnChainYieldsLockedProductResponse


class OnChainYieldsApi:
    """API Client for OnChainYieldsApi endpoints."""

    def __init__(
        self,
        configuration: ConfigurationRestAPI = None,
        session: Session = None,
        signer: Signers = None,
    ) -> None:
        self._configuration = configuration
        self._session = session
        self._signer = signer

    def get_on_chain_yields_locked_personal_left_quota(
        self,
        project_id: str = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedPersonalLeftQuotaResponse]:
        """
                Get On-chain Yields Locked Personal Left Quota (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/personalLeftQuota
                https://developers.binance.com/docs/staking/on-chain-yields/account/Get-Onchain-Locked-Personal-Left-Quota

                Get On-chain Yields Locked Personal Left Quota

        Weight: 50

                Args:
                    project_id (str):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedPersonalLeftQuotaResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if project_id is None:
            raise RequiredError(
                field="project_id",
                error_message="Missing required parameter 'project_id'",
            )

        payload = {"project_id": project_id, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/personalLeftQuota",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedPersonalLeftQuotaResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_product_list(
        self,
        asset: Optional[str] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedProductListResponse]:
        """
                Get On-chain Yields Locked Product List (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/list
                https://developers.binance.com/docs/staking/on-chain-yields/account/

                Get available On-chain Yields Locked product list

        * Get available On-chain Yields Locked product list

        Weight: 50

                Args:
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedProductListResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "asset": asset,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/list",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedProductListResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_product_position(
        self,
        asset: Optional[str] = None,
        position_id: Optional[int] = None,
        project_id: Optional[str] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedProductPositionResponse]:
        """
                Get On-chain Yields Locked Product Position (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/position
                https://developers.binance.com/docs/staking/on-chain-yields/account/Get-Onchain-Locked-Product-Position

                Get On-chain Yields Locked Product Position

        Weight: 50

                Args:
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    position_id (Optional[int]):
                    project_id (Optional[str]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedProductPositionResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "asset": asset,
            "position_id": position_id,
            "project_id": project_id,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/position",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedProductPositionResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_redemption_record(
        self,
        position_id: Optional[int] = None,
        redeem_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedRedemptionRecordResponse]:
        """
                Get On-chain Yields Locked Redemption Record (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/history/redemptionRecord
                https://developers.binance.com/docs/staking/on-chain-yields/history/Get-Onchain-Locked-Redemption-Record

                Get On-chain Yields Locked Redemption Record

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    position_id (Optional[int]):
                    redeem_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedRedemptionRecordResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "position_id": position_id,
            "redeem_id": redeem_id,
            "asset": asset,
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/history/redemptionRecord",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedRedemptionRecordResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_rewards_history(
        self,
        position_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedRewardsHistoryResponse]:
        """
                Get On-chain Yields Locked Rewards History (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/history/rewardsRecord
                https://developers.binance.com/docs/staking/on-chain-yields/history/Get-Onchain-Locked-Rewards-History

                Get On-chain Yields Locked Rewards History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    position_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "position_id": position_id,
            "asset": asset,
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/history/rewardsRecord",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedRewardsHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_subscription_preview(
        self,
        project_id: str = None,
        amount: float = None,
        auto_subscribe: Optional[bool] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedSubscriptionPreviewResponse]:
        """
                Get On-chain Yields Locked Subscription Preview (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/subscriptionPreview
                https://developers.binance.com/docs/staking/on-chain-yields/earn/

                Get On-chain Yields Locked Subscription Preview

        Weight: 50

                Args:
                    project_id (str):
                    amount (float): Amount in SOL.
                    auto_subscribe (Optional[bool]): true or false, default true.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedSubscriptionPreviewResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if project_id is None:
            raise RequiredError(
                field="project_id",
                error_message="Missing required parameter 'project_id'",
            )
        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {
            "project_id": project_id,
            "amount": amount,
            "auto_subscribe": auto_subscribe,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/subscriptionPreview",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedSubscriptionPreviewResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_on_chain_yields_locked_subscription_record(
        self,
        purchase_id: Optional[str] = None,
        client_id: Optional[str] = None,
        asset: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetOnChainYieldsLockedSubscriptionRecordResponse]:
        """
                Get On-chain Yields Locked Subscription Record (USER_DATA)
                GET /sapi/v1/onchain-yields/locked/history/subscriptionRecord
                https://developers.binance.com/docs/staking/on-chain-yields/history/

                Get On-chain Yields Locked Subscription Record

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 50

                Args:
                    purchase_id (Optional[str]):
                    client_id (Optional[str]):
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetOnChainYieldsLockedSubscriptionRecordResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "purchase_id": purchase_id,
            "client_id": client_id,
            "asset": asset,
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/locked/history/subscriptionRecord",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetOnChainYieldsLockedSubscriptionRecordResponse,
            is_signed=True,
            signer=self._signer,
        )

    def on_chain_yields_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[OnChainYieldsAccountResponse]:
        """
                On-chain Yields Account (USER_DATA)
                GET /sapi/v1/onchain-yields/account
                https://developers.binance.com/docs/staking/on-chain-yields/account/Onchain-Account

                On-chain Yields Account query

        Weight: 50

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[OnChainYieldsAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/onchain-yields/account",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=OnChainYieldsAccountResponse,
            is_signed=True,
            signer=self._signer,
        )

    def redeem_on_chain_yields_locked_product(
        self,
        position_id: str = None,
        channel_id: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemOnChainYieldsLockedProductResponse]:
        """
                Redeem On-chain Yields Locked Product (TRADE)
                POST /sapi/v1/onchain-yields/locked/redeem
                https://developers.binance.com/docs/staking/on-chain-yields/earn/Redeem-Onchain-Locked-Product

                Redeem On-chain Yields Locked Product

        * You need to open `Enable Spot & Margin Trading` permission for the API Key which requests this endpoint.

        Weight: 1/3s per account

                Args:
                    position_id (str):
                    channel_id (Optional[str]):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemOnChainYieldsLockedProductResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if position_id is None:
            raise RequiredError(
                field="position_id",
                error_message="Missing required parameter 'position_id'",
            )

        payload = {
            "position_id": position_id,
            "channel_id": channel_id,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/onchain-yields/locked/redeem",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=RedeemOnChainYieldsLockedProductResponse,
            is_signed=True,
            signer=self._signer,
        )

    def set_on_chain_yields_locked_auto_subscribe(
        self,
        position_id: str = None,
        auto_subscribe: bool = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SetOnChainYieldsLockedAutoSubscribeResponse]:
        """
                Set On-chain Yields Locked Auto Subscribe(USER_DATA)
                POST /sapi/v1/onchain-yields/locked/setAutoSubscribe
                https://developers.binance.com/docs/staking/on-chain-yields/earn/Set-Onchain-Locked-Auto-Subscribe

                Set On-chain Yield locked auto subscribe

        Weight: 50

                Args:
                    position_id (str):
                    auto_subscribe (bool): true or false
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SetOnChainYieldsLockedAutoSubscribeResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if position_id is None:
            raise RequiredError(
                field="position_id",
                error_message="Missing required parameter 'position_id'",
            )
        if auto_subscribe is None:
            raise RequiredError(
                field="auto_subscribe",
                error_message="Missing required parameter 'auto_subscribe'",
            )

        payload = {
            "position_id": position_id,
            "auto_subscribe": auto_subscribe,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/onchain-yields/locked/setAutoSubscribe",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SetOnChainYieldsLockedAutoSubscribeResponse,
            is_signed=True,
            signer=self._signer,
        )

    def set_on_chain_yields_locked_product_redeem_option(
        self,
        position_id: str = None,
        redeem_to: str = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SetOnChainYieldsLockedProductRedeemOptionResponse]:
        """
                Set On-chain Yields Locked Product Redeem Option(USER_DATA)
                POST /sapi/v1/onchain-yields/locked/setRedeemOption
                https://developers.binance.com/docs/staking/on-chain-yields/earn/Set-Onchain-Locked-Redeem-Option

                Set On-chain Yields redeem option for Locked product

        Weight: 50

                Args:
                    position_id (str):
                    redeem_to (str): 'SPOT','FLEXIBLE'
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SetOnChainYieldsLockedProductRedeemOptionResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if position_id is None:
            raise RequiredError(
                field="position_id",
                error_message="Missing required parameter 'position_id'",
            )
        if redeem_to is None:
            raise RequiredError(
                field="redeem_to",
                error_message="Missing required parameter 'redeem_to'",
            )

        payload = {
            "position_id": position_id,
            "redeem_to": redeem_to,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/onchain-yields/locked/setRedeemOption",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SetOnChainYieldsLockedProductRedeemOptionResponse,
            is_signed=True,
            signer=self._signer,
        )

    def subscribe_on_chain_yields_locked_product(
        self,
        project_id: str = None,
        amount: float = None,
        auto_subscribe: Optional[bool] = None,
        source_account: Optional[str] = None,
        redeem_to: Optional[str] = None,
        channel_id: Optional[str] = None,
        client_id: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeOnChainYieldsLockedProductResponse]:
        """
                Subscribe On-chain Yields Locked Product(TRADE)
                POST /sapi/v1/onchain-yields/locked/subscribe
                https://developers.binance.com/docs/staking/on-chain-yields/earn/Subscribe-Onchain-Locked-Product

                Subscribe On-chain Yields Locked Product

        * You need to open `Enable Spot & Margin Trading` permission for the API Key which requests this endpoint.

        Weight: 200

                Args:
                    project_id (str):
                    amount (float): Amount in SOL.
                    auto_subscribe (Optional[bool]): true or false, default true.
                    source_account (Optional[str]): `SPOT`,`FUND`,`ALL`, default `SPOT`
                    redeem_to (Optional[str]): `SPOT`,`FLEXIBLE`, default `FLEXIBLE` Takes effect when Auto Subscribe is false
                    channel_id (Optional[str]):
                    client_id (Optional[str]):
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeOnChainYieldsLockedProductResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if project_id is None:
            raise RequiredError(
                field="project_id",
                error_message="Missing required parameter 'project_id'",
            )
        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {
            "project_id": project_id,
            "amount": amount,
            "auto_subscribe": auto_subscribe,
            "source_account": source_account,
            "redeem_to": redeem_to,
            "channel_id": channel_id,
            "client_id": client_id,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/onchain-yields/locked/subscribe",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SubscribeOnChainYieldsLockedProductResponse,
            is_signed=True,
            signer=self._signer,
        )



# coding: utf-8

"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from binance_sdk_staking.rest_api.models.eth_staking_account_response_holdings import (
    EthStakingAccountResponseHoldings,
)
from binance_sdk_staking.rest_api.models.eth_staking_account_response_profit import (
    EthStakingAccountResponseProfit,
)
from typing import Set
from typing_extensions import Self


class EthStakingAccountResponse(BaseModel):
    """
    EthStakingAccountResponse
    """  # noqa: E501

    holding_in_eth: Optional[StrictStr] = Field(default=None, alias="holdingInETH")
    holdings: Optional[EthStakingAccountResponseHoldings] = None
    thirty_days_profit_in_eth: Optional[StrictStr] = Field(
        default=None, alias="thirtyDaysProfitInETH"
    )
    profit: Optional[EthStakingAccountResponseProfit] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "holdingInETH",
        "holdings",
        "thirtyDaysProfitInETH",
        "profit",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def is_array(cls) -> bool:
        return False

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EthStakingAccountResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set(
            [
                "additional_properties",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of holdings
        if self.holdings:
            _dict["holdings"] = self.holdings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of profit
        if self.profit:
            _dict["profit"] = self.profit.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EthStakingAccountResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "holdingInETH": obj.get("holdingInETH"),
                "holdings": (
                    EthStakingAccountResponseHoldings.from_dict(obj["holdings"])
                    if obj.get("holdings") is not None
                    else None
                ),
                "thirtyDaysProfitInETH": obj.get("thirtyDaysProfitInETH"),
                "profit": (
                    EthStakingAccountResponseProfit.from_dict(obj["profit"])
                    if obj.get("profit") is not None
                    else None
                ),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



import platform
from importlib.metadata import version

from binance_common.configuration import ConfigurationRestAPI
from binance_common.constants import STAKING_REST_API_PROD_URL
from . import metadata
from .rest_api import StakingRestAPI

LIB_NAME = metadata.NAME
LIB_VERSION = version(LIB_NAME)


class Staking:
    """Staking API that exposes REST APIs in a single interface."""

    def __init__(self, config_rest_api: ConfigurationRestAPI = None) -> None:
        self._rest_api = None
        self._rest_api_config = (
            ConfigurationRestAPI() if config_rest_api is None else config_rest_api
        )

    @property
    def rest_api(self) -> StakingRestAPI:
        if self._rest_api is None and self._rest_api_config:
            self._rest_api_config.base_headers["User-Agent"] = (
                f"{LIB_NAME}/{LIB_VERSION} (Python/{platform.python_version()}; {platform.system()}; {platform.machine()})"
            )
            self._rest_api_config.base_path = (
                STAKING_REST_API_PROD_URL
                if self._rest_api_config.base_path is None
                else self._rest_api_config.base_path
            )
            self._rest_api = StakingRestAPI(self._rest_api_config)
        return self._rest_api



"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from typing import Optional
from requests import Session
from binance_common.configuration import ConfigurationRestAPI
from binance_common.errors import RequiredError
from binance_common.models import ApiResponse
from binance_common.signature import Signers
from binance_common.utils import send_request

from ..models import ClaimBoostRewardsResponse
from ..models import GetBnsolRateHistoryResponse
from ..models import GetBnsolRewardsHistoryResponse
from ..models import GetBoostRewardsHistoryResponse
from ..models import GetSolRedemptionHistoryResponse
from ..models import GetSolStakingHistoryResponse
from ..models import GetSolStakingQuotaDetailsResponse
from ..models import GetUnclaimedRewardsResponse
from ..models import RedeemSolResponse
from ..models import SolStakingAccountResponse
from ..models import SubscribeSolStakingResponse


class SolStakingApi:
    """API Client for SolStakingApi endpoints."""

    def __init__(
        self,
        configuration: ConfigurationRestAPI = None,
        session: Session = None,
        signer: Signers = None,
    ) -> None:
        self._configuration = configuration
        self._session = session
        self._signer = signer

    def claim_boost_rewards(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[ClaimBoostRewardsResponse]:
        """
                Claim Boost Rewards(TRADE)
                POST /sapi/v1/sol-staking/sol/claim
                https://developers.binance.com/docs/staking/sol-staking/staking/Claim-Boost-Rewards

                Claim Boost APR Airdrop Rewards

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[ClaimBoostRewardsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/sol-staking/sol/claim",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=ClaimBoostRewardsResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_bnsol_rate_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBnsolRateHistoryResponse]:
        """
                Get BNSOL Rate History(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/rateHistory
                https://developers.binance.com/docs/staking/sol-staking/history/Get-BNSOL-Rate-History

                Get BNSOL Rate History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBnsolRateHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/rateHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetBnsolRateHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_bnsol_rewards_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBnsolRewardsHistoryResponse]:
        """
                Get BNSOL rewards history(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/bnsolRewardsHistory
                https://developers.binance.com/docs/staking/sol-staking/history/Get-BNSOL-rewards-history

                Get BNSOL rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBnsolRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/bnsolRewardsHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetBnsolRewardsHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_boost_rewards_history(
        self,
        type: str = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetBoostRewardsHistoryResponse]:
        """
                Get Boost Rewards History(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/boostRewardsHistory
                https://developers.binance.com/docs/staking/sol-staking/history/Get-Boost-Rewards-History

                Get Boost rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    type (str): "CLAIM", "DISTRIBUTE", default "CLAIM"
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetBoostRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if type is None:
            raise RequiredError(
                field="type", error_message="Missing required parameter 'type'"
            )

        payload = {
            "type": type,
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/boostRewardsHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetBoostRewardsHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_sol_redemption_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolRedemptionHistoryResponse]:
        """
                Get SOL redemption history(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/redemptionHistory
                https://developers.binance.com/docs/staking/sol-staking/history/Get-SOL-redemption-history

                Get SOL redemption history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolRedemptionHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/redemptionHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetSolRedemptionHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_sol_staking_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolStakingHistoryResponse]:
        """
                Get SOL staking history(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/stakingHistory
                https://developers.binance.com/docs/staking/sol-staking/history/Get-SOL-staking-history

                Get SOL staking history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolStakingHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/stakingHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetSolStakingHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_sol_staking_quota_details(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetSolStakingQuotaDetailsResponse]:
        """
                Get SOL staking quota details(USER_DATA)
                GET /sapi/v1/sol-staking/sol/quota
                https://developers.binance.com/docs/staking/sol-staking/account/Get-SOL-staking-quota-details

                Get SOL staking quota

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetSolStakingQuotaDetailsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/quota",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetSolStakingQuotaDetailsResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_unclaimed_rewards(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetUnclaimedRewardsResponse]:
        """
                Get Unclaimed Rewards(USER_DATA)
                GET /sapi/v1/sol-staking/sol/history/unclaimedRewards
                https://developers.binance.com/docs/staking/sol-staking/history/Get-Unclaimed-Rewards

                Get Unclaimed rewards

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetUnclaimedRewardsResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/sol/history/unclaimedRewards",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetUnclaimedRewardsResponse,
            is_signed=True,
            signer=self._signer,
        )

    def redeem_sol(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemSolResponse]:
        """
                Redeem SOL(TRADE)
                POST /sapi/v1/sol-staking/sol/redeem
                https://developers.binance.com/docs/staking/sol-staking/staking/Redeem-SOL

                Redeem BNSOL get SOL

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemSolResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {"amount": amount, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/sol-staking/sol/redeem",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=RedeemSolResponse,
            is_signed=True,
            signer=self._signer,
        )

    def sol_staking_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SolStakingAccountResponse]:
        """
                SOL Staking account(USER_DATA)
                GET /sapi/v1/sol-staking/account
                https://developers.binance.com/docs/staking/sol-staking/account/SOL-Staking-account

                SOL Staking account

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SolStakingAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/sol-staking/account",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SolStakingAccountResponse,
            is_signed=True,
            signer=self._signer,
        )

    def subscribe_sol_staking(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeSolStakingResponse]:
        """
                Subscribe SOL Staking(TRADE)
                POST /sapi/v1/sol-staking/sol/stake
                https://developers.binance.com/docs/staking/sol-staking/staking/Subscribe-SOL-Staking

                Subscribe SOL Staking

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeSolStakingResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {"amount": amount, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/sol-staking/sol/stake",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SubscribeSolStakingResponse,
            is_signed=True,
            signer=self._signer,
        )



"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from .claim_boost_rewards_response import (
    ClaimBoostRewardsResponse as ClaimBoostRewardsResponse,
)
from .eth_staking_account_response import (
    EthStakingAccountResponse as EthStakingAccountResponse,
)
from .eth_staking_account_response_holdings import (
    EthStakingAccountResponseHoldings as EthStakingAccountResponseHoldings,
)
from .eth_staking_account_response_profit import (
    EthStakingAccountResponseProfit as EthStakingAccountResponseProfit,
)
from .get_bnsol_rate_history_response import (
    GetBnsolRateHistoryResponse as GetBnsolRateHistoryResponse,
)
from .get_bnsol_rate_history_response_rows_inner import (
    GetBnsolRateHistoryResponseRowsInner as GetBnsolRateHistoryResponseRowsInner,
)
from .get_bnsol_rate_history_response_rows_inner_boost_rewards_inner import (
    GetBnsolRateHistoryResponseRowsInnerBoostRewardsInner as GetBnsolRateHistoryResponseRowsInnerBoostRewardsInner,
)
from .get_bnsol_rewards_history_response import (
    GetBnsolRewardsHistoryResponse as GetBnsolRewardsHistoryResponse,
)
from .get_bnsol_rewards_history_response_rows_inner import (
    GetBnsolRewardsHistoryResponseRowsInner as GetBnsolRewardsHistoryResponseRowsInner,
)
from .get_boost_rewards_history_response import (
    GetBoostRewardsHistoryResponse as GetBoostRewardsHistoryResponse,
)
from .get_boost_rewards_history_response_rows_inner import (
    GetBoostRewardsHistoryResponseRowsInner as GetBoostRewardsHistoryResponseRowsInner,
)
from .get_current_eth_staking_quota_response import (
    GetCurrentEthStakingQuotaResponse as GetCurrentEthStakingQuotaResponse,
)
from .get_eth_redemption_history_response import (
    GetEthRedemptionHistoryResponse as GetEthRedemptionHistoryResponse,
)
from .get_eth_redemption_history_response_rows_inner import (
    GetEthRedemptionHistoryResponseRowsInner as GetEthRedemptionHistoryResponseRowsInner,
)
from .get_eth_staking_history_response import (
    GetEthStakingHistoryResponse as GetEthStakingHistoryResponse,
)
from .get_eth_staking_history_response_rows_inner import (
    GetEthStakingHistoryResponseRowsInner as GetEthStakingHistoryResponseRowsInner,
)
from .get_on_chain_yields_locked_personal_left_quota_response import (
    GetOnChainYieldsLockedPersonalLeftQuotaResponse as GetOnChainYieldsLockedPersonalLeftQuotaResponse,
)
from .get_on_chain_yields_locked_product_list_response import (
    GetOnChainYieldsLockedProductListResponse as GetOnChainYieldsLockedProductListResponse,
)
from .get_on_chain_yields_locked_product_list_response_rows_inner import (
    GetOnChainYieldsLockedProductListResponseRowsInner as GetOnChainYieldsLockedProductListResponseRowsInner,
)
from .get_on_chain_yields_locked_product_list_response_rows_inner_detail import (
    GetOnChainYieldsLockedProductListResponseRowsInnerDetail as GetOnChainYieldsLockedProductListResponseRowsInnerDetail,
)
from .get_on_chain_yields_locked_product_list_response_rows_inner_quota import (
    GetOnChainYieldsLockedProductListResponseRowsInnerQuota as GetOnChainYieldsLockedProductListResponseRowsInnerQuota,
)
from .get_on_chain_yields_locked_product_position_response import (
    GetOnChainYieldsLockedProductPositionResponse as GetOnChainYieldsLockedProductPositionResponse,
)
from .get_on_chain_yields_locked_product_position_response_rows_inner import (
    GetOnChainYieldsLockedProductPositionResponseRowsInner as GetOnChainYieldsLockedProductPositionResponseRowsInner,
)
from .get_on_chain_yields_locked_redemption_record_response import (
    GetOnChainYieldsLockedRedemptionRecordResponse as GetOnChainYieldsLockedRedemptionRecordResponse,
)
from .get_on_chain_yields_locked_redemption_record_response_rows_inner import (
    GetOnChainYieldsLockedRedemptionRecordResponseRowsInner as GetOnChainYieldsLockedRedemptionRecordResponseRowsInner,
)
from .get_on_chain_yields_locked_rewards_history_response import (
    GetOnChainYieldsLockedRewardsHistoryResponse as GetOnChainYieldsLockedRewardsHistoryResponse,
)
from .get_on_chain_yields_locked_rewards_history_response_rows_inner import (
    GetOnChainYieldsLockedRewardsHistoryResponseRowsInner as GetOnChainYieldsLockedRewardsHistoryResponseRowsInner,
)
from .get_on_chain_yields_locked_subscription_preview_response import (
    GetOnChainYieldsLockedSubscriptionPreviewResponse as GetOnChainYieldsLockedSubscriptionPreviewResponse,
)
from .get_on_chain_yields_locked_subscription_record_response import (
    GetOnChainYieldsLockedSubscriptionRecordResponse as GetOnChainYieldsLockedSubscriptionRecordResponse,
)
from .get_on_chain_yields_locked_subscription_record_response_rows_inner import (
    GetOnChainYieldsLockedSubscriptionRecordResponseRowsInner as GetOnChainYieldsLockedSubscriptionRecordResponseRowsInner,
)
from .get_sol_redemption_history_response import (
    GetSolRedemptionHistoryResponse as GetSolRedemptionHistoryResponse,
)
from .get_sol_redemption_history_response_rows_inner import (
    GetSolRedemptionHistoryResponseRowsInner as GetSolRedemptionHistoryResponseRowsInner,
)
from .get_sol_staking_history_response import (
    GetSolStakingHistoryResponse as GetSolStakingHistoryResponse,
)
from .get_sol_staking_history_response_rows_inner import (
    GetSolStakingHistoryResponseRowsInner as GetSolStakingHistoryResponseRowsInner,
)
from .get_sol_staking_quota_details_response import (
    GetSolStakingQuotaDetailsResponse as GetSolStakingQuotaDetailsResponse,
)
from .get_unclaimed_rewards_response import (
    GetUnclaimedRewardsResponse as GetUnclaimedRewardsResponse,
)
from .get_unclaimed_rewards_response_inner import (
    GetUnclaimedRewardsResponseInner as GetUnclaimedRewardsResponseInner,
)
from .get_wbeth_rate_history_response import (
    GetWbethRateHistoryResponse as GetWbethRateHistoryResponse,
)
from .get_wbeth_rate_history_response_rows_inner import (
    GetWbethRateHistoryResponseRowsInner as GetWbethRateHistoryResponseRowsInner,
)
from .get_wbeth_rewards_history_response import (
    GetWbethRewardsHistoryResponse as GetWbethRewardsHistoryResponse,
)
from .get_wbeth_rewards_history_response_rows_inner import (
    GetWbethRewardsHistoryResponseRowsInner as GetWbethRewardsHistoryResponseRowsInner,
)
from .get_wbeth_unwrap_history_response import (
    GetWbethUnwrapHistoryResponse as GetWbethUnwrapHistoryResponse,
)
from .get_wbeth_unwrap_history_response_rows_inner import (
    GetWbethUnwrapHistoryResponseRowsInner as GetWbethUnwrapHistoryResponseRowsInner,
)
from .get_wbeth_wrap_history_response import (
    GetWbethWrapHistoryResponse as GetWbethWrapHistoryResponse,
)
from .get_wbeth_wrap_history_response_rows_inner import (
    GetWbethWrapHistoryResponseRowsInner as GetWbethWrapHistoryResponseRowsInner,
)
from .on_chain_yields_account_response import (
    OnChainYieldsAccountResponse as OnChainYieldsAccountResponse,
)
from .redeem_eth_response import RedeemEthResponse as RedeemEthResponse
from .redeem_on_chain_yields_locked_product_response import (
    RedeemOnChainYieldsLockedProductResponse as RedeemOnChainYieldsLockedProductResponse,
)
from .redeem_sol_response import RedeemSolResponse as RedeemSolResponse
from .set_on_chain_yields_locked_auto_subscribe_response import (
    SetOnChainYieldsLockedAutoSubscribeResponse as SetOnChainYieldsLockedAutoSubscribeResponse,
)
from .set_on_chain_yields_locked_product_redeem_option_response import (
    SetOnChainYieldsLockedProductRedeemOptionResponse as SetOnChainYieldsLockedProductRedeemOptionResponse,
)
from .sol_staking_account_response import (
    SolStakingAccountResponse as SolStakingAccountResponse,
)
from .subscribe_eth_staking_response import (
    SubscribeEthStakingResponse as SubscribeEthStakingResponse,
)
from .subscribe_on_chain_yields_locked_product_response import (
    SubscribeOnChainYieldsLockedProductResponse as SubscribeOnChainYieldsLockedProductResponse,
)
from .subscribe_sol_staking_response import (
    SubscribeSolStakingResponse as SubscribeSolStakingResponse,
)
from .wrap_beth_response import WrapBethResponse as WrapBethResponse



"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from typing import Optional
from requests import Session
from binance_common.configuration import ConfigurationRestAPI
from binance_common.errors import RequiredError
from binance_common.models import ApiResponse
from binance_common.signature import Signers
from binance_common.utils import send_request

from ..models import EthStakingAccountResponse
from ..models import GetCurrentEthStakingQuotaResponse
from ..models import GetEthRedemptionHistoryResponse
from ..models import GetEthStakingHistoryResponse
from ..models import GetWbethRateHistoryResponse
from ..models import GetWbethRewardsHistoryResponse
from ..models import GetWbethUnwrapHistoryResponse
from ..models import GetWbethWrapHistoryResponse
from ..models import RedeemEthResponse
from ..models import SubscribeEthStakingResponse
from ..models import WrapBethResponse


class EthStakingApi:
    """API Client for EthStakingApi endpoints."""

    def __init__(
        self,
        configuration: ConfigurationRestAPI = None,
        session: Session = None,
        signer: Signers = None,
    ) -> None:
        self._configuration = configuration
        self._session = session
        self._signer = signer

    def eth_staking_account(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[EthStakingAccountResponse]:
        """
                ETH Staking account(USER_DATA)
                GET /sapi/v2/eth-staking/account
                https://developers.binance.com/docs/staking/eth-staking/account/ETH-Staking-account

                ETH Staking account

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[EthStakingAccountResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v2/eth-staking/account",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=EthStakingAccountResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_current_eth_staking_quota(
        self,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetCurrentEthStakingQuotaResponse]:
        """
                Get current ETH staking quota(USER_DATA)
                GET /sapi/v1/eth-staking/eth/quota
                https://developers.binance.com/docs/staking/eth-staking/account/Get-current-ETH-staking-quota

                Get current ETH staking quota

        Weight: 150

                Args:
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetCurrentEthStakingQuotaResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {"recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/eth/quota",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetCurrentEthStakingQuotaResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_eth_redemption_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetEthRedemptionHistoryResponse]:
        """
                Get ETH redemption history(USER_DATA)
                GET /sapi/v1/eth-staking/eth/history/redemptionHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-ETH-redemption-history

                Get ETH redemption history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetEthRedemptionHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/eth/history/redemptionHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetEthRedemptionHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_eth_staking_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetEthStakingHistoryResponse]:
        """
                Get ETH staking history(USER_DATA)
                GET /sapi/v1/eth-staking/eth/history/stakingHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-ETH-staking-history

                Get ETH staking history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetEthStakingHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/eth/history/stakingHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetEthStakingHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_wbeth_rate_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethRateHistoryResponse]:
        """
                Get WBETH Rate History(USER_DATA)
                GET /sapi/v1/eth-staking/eth/history/rateHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-BETH-Rate-History

                Get WBETH Rate History

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethRateHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/eth/history/rateHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetWbethRateHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_wbeth_rewards_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethRewardsHistoryResponse]:
        """
                Get WBETH rewards history(USER_DATA)
                GET /sapi/v1/eth-staking/eth/history/wbethRewardsHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-WBETH-rewards-history

                Get WBETH rewards history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethRewardsHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/eth/history/wbethRewardsHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetWbethRewardsHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_wbeth_unwrap_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethUnwrapHistoryResponse]:
        """
                Get WBETH unwrap history(USER_DATA)
                GET /sapi/v1/eth-staking/wbeth/history/unwrapHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-WBETH-unwrap-history

                Get WBETH unwrap history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethUnwrapHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/wbeth/history/unwrapHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetWbethUnwrapHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def get_wbeth_wrap_history(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        current: Optional[int] = None,
        size: Optional[int] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[GetWbethWrapHistoryResponse]:
        """
                Get WBETH wrap history(USER_DATA)
                GET /sapi/v1/eth-staking/wbeth/history/wrapHistory
                https://developers.binance.com/docs/staking/eth-staking/history/Get-WBETH-wrap-history

                Get WBETH wrap history

        * The time between `startTime` and `endTime` cannot be longer than 3 months.
        * If `startTime` and `endTime` are both not sent, then the last 30 days' data will be returned.
        * If `startTime` is sent but `endTime` is not sent, the next 30 days' data beginning from `startTime` will be returned.
        * If `endTime` is sent but `startTime` is not sent, the 30 days' data before `endTime` will be returned.

        Weight: 150

                Args:
                    start_time (Optional[int]):
                    end_time (Optional[int]):
                    current (Optional[int]): Currently querying page. Start from 1. Default:1
                    size (Optional[int]): Default:10, Max:100
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[GetWbethWrapHistoryResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        payload = {
            "start_time": start_time,
            "end_time": end_time,
            "current": current,
            "size": size,
            "recv_window": recv_window,
        }

        return send_request(
            self._session,
            self._configuration,
            method="GET",
            path="/sapi/v1/eth-staking/wbeth/history/wrapHistory",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=GetWbethWrapHistoryResponse,
            is_signed=True,
            signer=self._signer,
        )

    def redeem_eth(
        self,
        amount: float = None,
        asset: Optional[str] = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[RedeemEthResponse]:
        """
                Redeem ETH(TRADE)
                POST /sapi/v1/eth-staking/eth/redeem
                https://developers.binance.com/docs/staking/eth-staking/staking/Redeem-ETH

                Redeem WBETH or BETH and get ETH

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    asset (Optional[str]): WBETH or BETH, default to BETH
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[RedeemEthResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {"amount": amount, "asset": asset, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/eth-staking/eth/redeem",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=RedeemEthResponse,
            is_signed=True,
            signer=self._signer,
        )

    def subscribe_eth_staking(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[SubscribeEthStakingResponse]:
        """
                Subscribe ETH Staking(TRADE)
                POST /sapi/v2/eth-staking/eth/stake
                https://developers.binance.com/docs/staking/eth-staking/staking/Subscribe-ETH-Staking

                Subscribe ETH Staking

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[SubscribeEthStakingResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {"amount": amount, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v2/eth-staking/eth/stake",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=SubscribeEthStakingResponse,
            is_signed=True,
            signer=self._signer,
        )

    def wrap_beth(
        self,
        amount: float = None,
        recv_window: Optional[int] = None,
    ) -> ApiResponse[WrapBethResponse]:
        """
                Wrap BETH(TRADE)
                POST /sapi/v1/eth-staking/wbeth/wrap
                https://developers.binance.com/docs/staking/eth-staking/staking/Wrap-BETH

                Wrap BETH

        * You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.

        Weight: 150

                Args:
                    amount (float): Amount in SOL.
                    recv_window (Optional[int]):

                Returns:
                    ApiResponse[WrapBethResponse]

                Raises:
                    RequiredError: If a required parameter is missing.

        """

        if amount is None:
            raise RequiredError(
                field="amount", error_message="Missing required parameter 'amount'"
            )

        payload = {"amount": amount, "recv_window": recv_window}

        return send_request(
            self._session,
            self._configuration,
            method="POST",
            path="/sapi/v1/eth-staking/wbeth/wrap",
            payload=payload,
            time_unit=self._configuration.time_unit,
            response_model=WrapBethResponse,
            is_signed=True,
            signer=self._signer,
        )
